@@ -24,7 +24,7 @@ from cl_lang import lang
 tr = lang()
 tr.setLocalDomain('cl_lib')
 tr.setLanguage(sys.modules[__name__])
-optparse._ = _
+tr.setLanguage(optparse)
 
 def check_choice_regignore(option, opt, value):
     """Check choice with registry independence"""
