@@ -14,7 +14,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-__version__ = "2.2.28"
+__version__ = "2.2.29"
 __app__ = "calculate-lib"
 
 import sys, os, stat, re
@@ -241,8 +241,8 @@ class updateUserConfigs(shareUpdateConfigs):
         flagUpdate, mergePrograms = self.getFlagUpdAndInstPrograms()
         # X session user + configured local users (if user profile was not
         # configured then there is no need setup package for this user
-        xUsers = list((set(self.getXUsers()) |
-                       set(self.getConfiguredPasswdUsers())))
+        xUsers = filter(lambda x:not "(unknown)" in x,list((set(self.getXUsers()) |
+                       set(self.getConfiguredPasswdUsers()))))
         if not xUsers:
             self.logger.info(_("Package %s") %nameProgram)
             self.logger.warn(_("X sessions users not found"))
